==> qt-creator-2.0.0-rc1-src.zip: qt-creator-2.0.0-rc1-src/src/plugins/designer/designercontext.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2010 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** Commercial Usage
**
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** If you are unsure which license is appropriate for your use, please
** contact the sales department at http://qt.nokia.com/contact.
**
**************************************************************************/

#ifndef DESIGNERCONTEXT_H
#define DESIGNERCONTEXT_H

#include <coreplugin/icontext.h>
#include <QList>

QT_BEGIN_NAMESPACE
class QWidget;
QT_END_NAMESPACE

namespace Designer {
namespace Internal {

class DesignerContext : public Core::IContext
{
    Q_DISABLE_COPY(DesignerContext)
public:
    explicit DesignerContext(const QList<int> contexts,
                             QWidget *widget,
                             QObject *parent = 0);

    virtual QList<int> context() const;
    virtual QWidget *widget();
    virtual QString contextHelpId() const;

private:
    const QList<int> m_context;
    QWidget *m_widget;
};

} // namespace Internal
} // namespace Designer

#endif // DESIGNERCONTEXT_H

==> qt-creator-2.1.0-src.zip: qt-creator-2.1.0-src/src/plugins/designer/designercontext.h <==
/**************************************************************************
**
** This file is part of Qt Creator
**
** Copyright (c) 2011 Nokia Corporation and/or its subsidiary(-ies).
**
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** No Commercial Usage
**
** This file contains pre-release code and may not be distributed.
** You may use this file in accordance with the terms and conditions
** contained in the Technology Preview License Agreement accompanying
** this package.
**
** GNU Lesser General Public License Usage
**
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
**
**************************************************************************/

#ifndef DESIGNERCONTEXT_H
#define DESIGNERCONTEXT_H

#include <coreplugin/icontext.h>

#include <QtCore/QList>

QT_BEGIN_NAMESPACE
class QWidget;
QT_END_NAMESPACE

namespace Designer {
namespace Internal {

class DesignerContext : public Core::IContext
{
    Q_DISABLE_COPY(DesignerContext)
public:
    explicit DesignerContext(const Core::Context &contexts,
                             QWidget *widget,
                             QObject *parent = 0);

    virtual Core::Context context() const;
    virtual QWidget *widget();
    virtual QString contextHelpId() const;

private:
    const Core::Context m_context;
    QWidget *m_widget;
};

} // namespace Internal
} // namespace Designer

#endif // DESIGNERCONTEXT_H
